
/*
 * $Id: store_dir_stat.c,v 1.135.2.3 2005/03/26 02:50:54 hno Exp $
 *
 * DEBUG: section 47    Store Directory Routines
 * AUTHOR: Duane Wessels
 *
 * SQUID Web Proxy Cache          http://www.squid-cache.org/
 * ----------------------------------------------------------
 *
 *  Squid is the result of efforts by numerous individuals from
 *  the Internet community; see the CONTRIBUTORS file for full
 *  details.   Many organizations have provided support for Squid's
 *  development; see the SPONSORS file for full details.  Squid is
 *  Copyrighted (C) 2001 by the Regents of the University of
 *  California; see the COPYRIGHT file for full details.  Squid
 *  incorporates software developed and/or copyrighted by other
 *  sources; see the CREDITS file for full details.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *  
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *  
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 *
 */

#include "squid.h"
#include "store_dir_stat.h"

int
storeDirGetBlkSize(const char *path, int *blksize)
{
#if HAVE_STATVFS
    struct statvfs sfs;
    if (statvfs(path, &sfs)) {
	debug(50, 1) ("%s: %s\n", path, xstrerror());
	*blksize = 2048;
	return 1;
    }
    *blksize = (int) sfs.f_frsize;
#else
    struct statfs sfs;
    if (statfs(path, &sfs)) {
	debug(50, 1) ("%s: %s\n", path, xstrerror());
	*blksize = 2048;
	return 1;
    }
    *blksize = (int) sfs.f_bsize;
#endif
    /*
     * Sanity check; make sure we have a meaningful value.
     */
    if (*blksize < 512)
	*blksize = 2048;
    return 0;
}

#define fsbtoblk(num, fsbs, bs) \
    (((fsbs) != 0 && (fsbs) < (bs)) ? \
            (num) / ((bs) / (fsbs)) : (num) * ((fsbs) / (bs)))

#if HAVE_STATVFS
int
storeDirGetUFSStats(const char *path, fsblkcnt_t *totl_kb, fsblkcnt_t *free_kb, fsfilcnt_t *totl_in, fsfilcnt_t *free_in)
#else
int
storeDirGetUFSStats(const char *path, int *totl_kb, int *free_kb, int *totl_in, int *free_in)
#endif
{
#if HAVE_STATVFS
    struct statvfs sfs;
    if (statvfs(path, &sfs)) {
	debug(50, 1) ("%s: %s\n", path, xstrerror());
	return 1;
    }
    *totl_kb = fsbtoblk(sfs.f_blocks, sfs.f_frsize, 1024);
    *free_kb = fsbtoblk(sfs.f_bfree, sfs.f_frsize, 1024);
    *totl_in = sfs.f_files;
    *free_in = sfs.f_ffree;
#else
    struct statfs sfs;
    if (statfs(path, &sfs)) {
	debug(50, 1) ("%s: %s\n", path, xstrerror());
	return 1;
    }
    *totl_kb = fsbtoblk(sfs.f_blocks, sfs.f_bsize, 1024);
    *free_kb = fsbtoblk(sfs.f_bfree, sfs.f_bsize, 1024);
    *totl_in = sfs.f_files;
    *free_in = sfs.f_ffree;
#endif
    return 0;
}
